@@ -1,7 +1,7 @@
 package Module::DataPack;
 
-our $DATE = '2015-07-05'; # DATE
-our $VERSION = '0.07'; # VERSION
+our $DATE = '2015-07-08'; # DATE
+our $VERSION = '0.08'; # VERSION
 
 use 5.010001;
 use strict;
@@ -130,6 +130,8 @@ sub datapack_modules {
     my @res;
 
     push @res, $args{preamble} if defined $args{preamble};
+
+    # how to line number (# line): position of __DATA__ + 1 (DSS header) + number of header lines + 1 (blank line) + $order+1 (number of ### file ### header) + lineoffset
     push @res, <<'_';
 # BEGIN DATAPACK CODE
 {
@@ -181,7 +183,7 @@ my $header_line = <$fh>;
             read DATA, my($content), $toc->{$_[1]}[1];
             my ($order, $lineoffset) = split(';', $toc->{$_[1]}[2]);
             $content =~ s/^ //gm;
-            $content = "# line ".($data_linepos + 1 + keys(%$toc) + 1 + $order + $lineoffset)." \"".__FILE__."\"\n" . $content;
+            $content = "# line ".($data_linepos + 1 + keys(%$toc) + 1 + $order+1 + $lineoffset)." \"".__FILE__."\"\n" . $content;
             open my $fh, '<', \$content
                 or die "DataPacker error loading $_[1] (could be a perl installation issue?)";
             return $fh;
@@ -242,7 +244,7 @@ Module::DataPack - Like Module::FatPack, but uses datapacking instead of fatpack
 
 =head1 VERSION
 
-This document describes version 0.07 of Module::DataPack (from Perl distribution Module-DataPack), released on 2015-07-05.
+This document describes version 0.08 of Module::DataPack (from Perl distribution Module-DataPack), released on 2015-07-08.
 
 =head1 SEE ALSO
 
